# NLPLab_toolkit
[![Documentation Status](https://readthedocs.org/projects/nlplab-toolkit/badge/?version=latest)](https://nlplab-toolkit.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/NTHU-NLPLab-toolkit.svg)](https://badge.fury.io/py/NTHU-NLPLab-toolkit) ![test](https://github.com/NTHU-NLPLAB/NLPLab_toolkit/workflows/Python%20package/badge.svg) 

please follow [pep8](https://www.python.org/dev/peps/pep-0008/), [black](https://github.com/psf/black) style and use [doctest](https://docs.python.org/3/library/doctest.html) to test code

This toolkit is maintained by [NTHU NLP Lab](https://www.nlplab.cc/)  
You can check the [documentation](https://nlplab-toolkit.readthedocs.io/en/latest/)